;; Copy this file to ~/.emacs (home directory called ".emacs") to get
;; a basic appearance and behavior discussed in the session.  Comment
;; out portions of the code that don't suit you like "I wan't scroll
;; bars" so comment out the code that hides scroll bars.

;; simple .emacs file with some basic mode customizations
(ido-mode 1)                            ;; better auto completion for files/buffers
(blink-cursor-mode 0)                   ;; disable blinking cursor to prevent mental trauma
(show-paren-mode 1)                     ;; shows matching parens or failure to match
(global-auto-revert-mode 1)             ;; reload files that change on disk
(column-number-mode 1)                  ;; show column numbers in mode line
(global-hl-line-mode 1)                 ;; change the color of the line the cursor is on

(setq-default truncate-lines t)         ;; default to NOT wrapping long lines in display
(tool-bar-mode 0)                       ;; hide the tool bar
(menu-bar-mode 0)                       ;; hide the "File Edit..." menu
(scroll-bar-mode -1)                    ;; hide the scroll bars

(setq inhibit-startup-screen t)         ;; don't show the "splash" screen
(setq initial-scratch-message           ;; put this text in the scratch buffer
      ";; Scratch that!\n")

(global-set-key "\M-o"  'other-window)        ; change quickly between windows, default C-x o
(global-set-key "\C-cc" (quote compile))      ; compile in buffers directory, usually via 'make'
(global-set-key "\C-cl" 'auto-fill-mode)      ; toggle whether emacs wraps/newlines text or not
(global-set-key "\C-cp" 'replace-string)      ; query for find/replace and replace all
(global-set-key "\M-j"  'join-line)           ; join current line with line above
(global-set-key "\C-xg" 'magit-status)        ; emacs interface to git called 'Magit'
(global-set-key "\C-ck" 'browse-kill-ring)    ; examine the "cut" text newest to oldest
(global-set-key "\C-cv" 'find-file-at-point)  ; treat text at point as a file name and open it
(global-set-key "\C-cd" 'set-comment-column)  ; set how for righ-hand comments appear, use C-; to introduce comments


;; Set up the package manager so it reads from the popular MELPA
;; pacakge server as well. Access packages via M-x list-packages
(require 'package)
(add-to-list 'package-archives '("melpa" . "http://melpa.milkbox.net/packages/") t)
(package-initialize)


;; define a simple Hello World function
(defun hello-world ()                            ; define a func, 0 args                        
  "Say hello world in the messages/mini-buffer"  ; documentation string                         
  (interactive)                                  ; make func interactive (via M-x hello-world)  
  (message "hello world"))                       ; put a messag ein the mini buffer


;; Define a more complex function which opens a shell in an adjacent
;; window in the directory corresponding to the current directory.
(defun shell-jump-to-current-directory ()
  "Open *shell* and change to directory of the given
buffer. Start's shell if needed. Handles dired-mode specially to
look for the 'closest' subdirectory when multiple directories are
open."
  (interactive)
  (let* ((dir (if (equal major-mode 'dired-mode)          ; using dired?
                  (dired-find-directory-at-point)         ; dired mode: find closest directory
                  default-directory))                     ; other buffer: use default dir for buffer
         (dir (replace-regexp-in-string " " "\\\\ " dir)) ; escape spaces
	 (cmd (concat "cd " dir)))                        ; add on the 'cd' 
    (when (one-window-p)                                  ; in there is only one window
      (split-window-right))                               ; split to 2 windows, left/right
    (if (get-buffer "*shell*")                            ; check if shell is already active
      (progn                                              ; yes (true case)
        (other-window 1)                                  ; switch to other window
        (switch-to-buffer "*shell*"))                     ; change to the *shell* buffer
      (progn                                              ; no (false case)
        (shell)                                           ; start the shell
        (sleep-for 0 10)))                                ; 10 millisec delay to let the shell get started before sending input (hack)
    (end-of-buffer)                                       ; move point to the end of the shell buffer
    (insert cmd)                                          ; insert the 'cd' command
    (comint-send-input)))                                 ; signal the shell that a command has been sent

(global-set-key "\C-cj" 'shell-jump-to-current-directory) ; set the key stroke "C-c j" to execute the above shell function
